go_router_flow library

A declarative router for Flutter based on Navigation 2 supporting deep linking, data-driven routes and more.

Classes

CustomTransitionPage<T>
Page with custom transition functionality.
GoRoute Get started Configuration Redirection Transition animations Named routes
A route that is displayed visually above the matching parent route using the Navigator.
GoRouteData Type-safe routes
Baseclass for supporting Type-safe routing.
GoRouter Get started Upgrading Configuration Navigation Redirection Web Deep linking Named routes Error handling
The route configuration for the app.
GoRouterState
The route state during routing.
InheritedGoRouter
GoRouter implementation of InheritedWidget.
NoTransitionPage<T>
Custom transition page with no transition.
RouteBase
The base class for GoRoute and ShellRoute.
RouteData
A superclass for each route data
ShellRoute Configuration
A route that displays a UI shell around the matching child route.
ShellRouteData
Base class for supporting nested navigation
TypedGoRoute<T extends GoRouteData>
A superclass for each typed go route descendant
TypedRoute<T extends RouteData>
A superclass for each typed route descendant
TypedShellRoute<T extends ShellRouteData>
A superclass for each typed shell route descendant

Extensions

GoRouterHelper on BuildContext
Dart extension to add navigation function to a BuildContext object, e.g. context.go('/');

Typedefs

GoRouterPageBuilder = Page Function(BuildContext context, GoRouterState state)
The page builder for GoRoute.
GoRouterRedirect = FutureOr<String?> Function(BuildContext context, GoRouterState state)
The signature of the redirect callback.
GoRouterWidgetBuilder = Widget Function(BuildContext context, GoRouterState state)
The widget builder for GoRoute.